@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.23 2005/02/06 14:35:58 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.25.4.1 2005/10/27 20:49:59 chpe Exp $
  */
 
 #include "config.h"
@@ -50,6 +50,7 @@
 struct EphyCertificatesExtensionPrivate
 {
 	GtkWidget *cert_manager;
+	GtkWidget *device_manager;
 };
 
 typedef struct
@@ -59,6 +60,7 @@ typedef struct
 } WindowData;
 
 #define CERT_MANAGER_URL	"chrome://pippki/content/certManager.xul"
+#define DEVICE_MANAGER_URL	"chrome://pippki/content/device_manager.xul"
 #define WINDOW_DATA_KEY "EphyCertificatesExtensionWindowData"
 
 static void ephy_certificates_extension_class_init	 (EphyCertificatesExtensionClass *klass);
@@ -122,15 +124,24 @@ static void
 ephy_certificates_extension_finalize (GObject *object)
 {
 	EphyCertificatesExtension *extension = EPHY_CERTIFICATES_EXTENSION (object);
+	EphyCertificatesExtensionPrivate *priv = extension->priv;
 
 	LOG ("EphyCertificatesExtension finalising");
 
-	if (extension->priv->cert_manager)
+	if (priv->cert_manager)
 	{
-		g_object_remove_weak_pointer (G_OBJECT (extension->priv->cert_manager),
-					      (gpointer *) &extension->priv->cert_manager);
-		gtk_widget_destroy (extension->priv->cert_manager);
-		extension->priv->cert_manager = NULL;
+		g_object_remove_weak_pointer (G_OBJECT (priv->cert_manager),
+					      (gpointer *) &priv->cert_manager);
+		gtk_widget_destroy (priv->cert_manager);
+		priv->cert_manager = NULL;
+	}
+
+	if (priv->device_manager)
+	{
+		g_object_remove_weak_pointer (G_OBJECT (priv->device_manager),
+					      (gpointer *) &priv->device_manager);
+		gtk_widget_destroy (priv->device_manager);
+		priv->device_manager = NULL;
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -140,12 +151,13 @@ static void
 manage_certificates_cb (GtkAction *action,
 			EphyCertificatesExtension *extension)
 {
+	EphyCertificatesExtensionPrivate *priv = extension->priv;
 	EphyEmbedSingle *single;
 	GtkWidget *manager, *window;
 
-	if (extension->priv->cert_manager != NULL)
+	if (priv->cert_manager != NULL)
 	{
-		gtk_window_present (GTK_WINDOW (extension->priv->cert_manager));
+		gtk_window_present (GTK_WINDOW (priv->cert_manager));
 		return;
 	}  
 
@@ -155,10 +167,44 @@ manage_certificates_cb (GtkAction *action,
 	g_return_if_fail (manager != NULL);
 
 	window = gtk_widget_get_toplevel (manager);
+	g_return_if_fail (GTK_WIDGET_TOPLEVEL (window));
 
-	extension->priv->cert_manager = window;
-	g_object_add_weak_pointer (G_OBJECT (extension->priv->cert_manager),
-				   (gpointer *) &extension->priv->cert_manager);
+	gtk_window_set_role (GTK_WINDOW (window), "epiphany-certificate-manager");
+	gtk_window_set_title (GTK_WINDOW (window), _("Certificates"));
+
+	priv->cert_manager = window;
+	g_object_add_weak_pointer (G_OBJECT (priv->cert_manager),
+				   (gpointer *) &priv->cert_manager);
+}
+
+static void
+manage_devices_cb (GtkAction *action,
+		   EphyCertificatesExtension *extension)
+{
+	EphyCertificatesExtensionPrivate *priv = extension->priv;
+	EphyEmbedSingle *single;
+	GtkWidget *manager, *window;
+
+	if (priv->device_manager != NULL)
+	{
+		gtk_window_present (GTK_WINDOW (priv->device_manager));
+		return;
+	}  
+
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	manager = ephy_embed_single_open_window (single, NULL, DEVICE_MANAGER_URL,
+						 "", "all,chrome");
+	g_return_if_fail (manager != NULL);
+
+	window = gtk_widget_get_toplevel (manager);
+	g_return_if_fail (GTK_WIDGET_TOPLEVEL (window));
+
+	gtk_window_set_role (GTK_WINDOW (window), "epiphany-security-device-manager");
+	gtk_window_set_title (GTK_WINDOW (window), _("Security Devices"));
+
+	priv->device_manager = window;
+	g_object_add_weak_pointer (G_OBJECT (priv->device_manager),
+				   (gpointer *) &priv->device_manager);
 }
 
 static void
@@ -192,7 +238,7 @@ sync_security_status (EphyTab *tab,
 	g_return_if_fail (action != NULL);
 
 	is_secure = ephy_tab_get_security_level (tab) > EPHY_EMBED_STATE_IS_INSECURE;
-	g_object_set (action, "sensitive", is_secure, NULL);
+	gtk_action_set_sensitive (action, is_secure);
 }
 
 static void
@@ -268,17 +314,22 @@ padlock_button_press_cb (GtkWidget *ebox,
 	return FALSE;
 }
 
-static GtkActionEntry action_entries_1 [] =
+static const GtkActionEntry action_entries_1 [] =
 {
 	{ "ToolsCertificateManager",
 	  NULL /* stock icon */,
 	  N_("Manage _Certificates"),
 	  NULL, /* shortcut key */
 	  N_("Manage your certificates"),
-	  G_CALLBACK (manage_certificates_cb) }
+	  G_CALLBACK (manage_certificates_cb) },
+	{ "ToolsSecurityDevicesManager",
+	  NULL /* stock icon */,
+	  N_("Manage Security _Devices"),
+	  NULL, /* shortcut key */
+	  N_("Manage your security devices"),
+	  G_CALLBACK (manage_devices_cb) }
 };
-static const guint n_action_entries_1 = G_N_ELEMENTS (action_entries_1);
-static GtkActionEntry action_entries_2 [] =
+static const GtkActionEntry action_entries_2 [] =
 {
 	{ "ViewServerCertificate",
 	  NULL /* stock icon */,
@@ -287,7 +338,6 @@ static GtkActionEntry action_entries_2 [] =
 	  N_("Display the web server's certificate"),
 	  G_CALLBACK (view_certificate_cb) }
 };
-static const guint n_action_entries_2 = G_N_ELEMENTS (action_entries_2);
 
 static void
 free_window_data (WindowData *data)
@@ -338,9 +388,9 @@ impl_attach_window (EphyExtension *ext,
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 
 	gtk_action_group_add_actions (action_group, action_entries_1,
-				      n_action_entries_1, ext);
+				      G_N_ELEMENTS (action_entries_1), ext);
 	gtk_action_group_add_actions (action_group, action_entries_2,
-				      n_action_entries_2, window);
+				      G_N_ELEMENTS (action_entries_2), window);
 
 	gtk_ui_manager_insert_action_group (manager, action_group, 0);
 
@@ -360,6 +410,10 @@ impl_attach_window (EphyExtension *ext,
 			       "ToolsCertificateManagerItem",
 			       "ToolsCertificateManager",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+			       "ToolsSecurityDevicesManagerItem",
+			       "ToolsSecurityDevicesManager",
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
 			       "ToolsSCSep2", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
